@@ -57,6 +57,7 @@ if not ENV_FILE.exists():
     from pylav.constants.config.env_var import POSTGRES_PORT as POSTGRES_PORT
     from pylav.constants.config.env_var import POSTGRES_SOCKET as POSTGRES_SOCKET
     from pylav.constants.config.env_var import POSTGRES_USER as POSTGRES_USER
+    from pylav.constants.config.env_var import PREFER_PARTIAL_TRACKS as PREFER_PARTIAL_TRACKS
     from pylav.constants.config.env_var import READ_CACHING_ENABLED as READ_CACHING_ENABLED
     from pylav.constants.config.env_var import REDIS_FULL_ADDRESS_RESPONSE_CACHE as REDIS_FULL_ADDRESS_RESPONSE_CACHE
     from pylav.constants.config.env_var import (
@@ -69,6 +70,7 @@ if not ENV_FILE.exists():
         TASK_TIMER_UPDATE_EXTERNAL_PLAYLISTS_DAYS as TASK_TIMER_UPDATE_EXTERNAL_PLAYLISTS_DAYS,
     )
     from pylav.constants.config.env_var import USE_BUNDLED_EXTERNAL_PYLAV_NODE as USE_BUNDLED_EXTERNAL_PYLAV_NODE
+
 else:
     LOGGER.info("%s exist - Environment variables will be read from it", ENV_FILE)
     from pylav.constants.config.file import DEFAULT_SEARCH_SOURCE as DEFAULT_SEARCH_SOURCE
@@ -96,6 +98,7 @@ else:
     from pylav.constants.config.file import POSTGRES_PORT as POSTGRES_PORT
     from pylav.constants.config.file import POSTGRES_SOCKET as POSTGRES_SOCKET
     from pylav.constants.config.file import POSTGRES_USER as POSTGRES_USER
+    from pylav.constants.config.file import PREFER_PARTIAL_TRACKS as PREFER_PARTIAL_TRACKS
     from pylav.constants.config.file import READ_CACHING_ENABLED as READ_CACHING_ENABLED
     from pylav.constants.config.file import REDIS_FULL_ADDRESS_RESPONSE_CACHE as REDIS_FULL_ADDRESS_RESPONSE_CACHE
     from pylav.constants.config.file import (
